@@ -7,13 +7,8 @@ import IMP.atom as atom
 import IMP.algebra as alg
 import IMP.core as core
 import logging
-
 import networkx as nx
 
-try:
-    set = set
-except NameError:
-    from sets import Set as set
 
 log = logging.getLogger("buildxlinks")
 
@@ -168,7 +163,7 @@ class XlinksDict(dict):
         """
 
 
-class DockOrder (object):
+class DockOrder:
 
     """
         Compute the order of the docking experiments. The order is derived
