@@ -6,11 +6,12 @@ import IMP.algebra
 
 
 def _make_test_decorator(m):
-    p = IMP.kernel.Particle(m)
+    p = IMP.Particle(m)
     v = IMP.algebra.Vector3D(1.0, 2.0, 3.0)
     s = IMP.algebra.Sphere3D(v, 4.0)
     IMP.core.XYZR.setup_particle(p, s)
-    return IMP.atom.LennardJones.setup_particle(p, 0.5)
+    with IMP.allow_deprecated():
+        return IMP.atom.LennardJones.setup_particle(p, 0.5)
 
 
 class Tests(IMP.test.TestCase):
@@ -19,22 +20,23 @@ class Tests(IMP.test.TestCase):
 
     def test_create(self):
         """Check creation of LennardJones decorators"""
-        m = IMP.kernel.Model()
-        p = IMP.kernel.Particle(m)
+        m = IMP.Model()
+        p = IMP.Particle(m)
         s = IMP.algebra.Sphere3D(IMP.algebra.Vector3D(1.0, 2.0, 3.0), 4.0)
         # Can create decorators using well depth, only if the particle is
         # already an XYZ
-        p = IMP.kernel.Particle(m)
+        p = IMP.Particle(m)
         IMP.core.XYZR.setup_particle(p, s)
-        IMP.atom.LennardJones.setup_particle(p, 0.5)
-        p = IMP.kernel.Particle(m)
-        if IMP.base.get_check_level() != IMP.base.NONE:
-            self.assertRaises(IMP.base.UsageException,
+        with IMP.allow_deprecated():
+            IMP.atom.LennardJones.setup_particle(p, 0.5)
+        p = IMP.Particle(m)
+        with IMP.allow_deprecated():
+            self.assertRaisesUsageException(
                               IMP.atom.LennardJones.setup_particle, p, 0.5)
 
     def test_get_set(self):
         """Check get/set methods of LennardJones decorators"""
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         c = _make_test_decorator(m)
         self.assertAlmostEqual(c.get_well_depth(), 0.5, delta=1e-6)
         c.set_well_depth(2.5)
@@ -42,7 +44,7 @@ class Tests(IMP.test.TestCase):
 
     def test_show(self):
         """Check show method of LennardJones decorators"""
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         c = _make_test_decorator(m)
         self.assertIn(' well depth= ', str(c))
 
