@@ -10,19 +10,22 @@ from test_coulomb import place_xyzs
 
 
 def make_test_pair_score(min_distance=9.0, max_distance=10.0):
-    m = IMP.kernel.Model()
-    p0 = IMP.kernel.Particle(m)
+    m = IMP.Model()
+    p0 = m.add_particle("p0")
     sph = IMP.algebra.Sphere3D(IMP.algebra.Vector3D(0, 0, 0), 1.0)
-    IMP.core.XYZR.setup_particle(p0, sph)
-    d0 = IMP.atom.LennardJones.setup_particle(p0, 1.0)
-    p1 = IMP.kernel.Particle(m)
-    IMP.core.XYZR.setup_particle(p1, sph)
-    d1 = IMP.atom.LennardJones.setup_particle(p1, 1.0)
+    IMP.core.XYZR.setup_particle(m, p0, sph)
+    with IMP.allow_deprecated():
+        d0 = IMP.atom.LennardJones.setup_particle(m, p0, 1.0)
+    p1 = m.add_particle("p1")
+    IMP.core.XYZR.setup_particle(m, p1, sph)
+    with IMP.allow_deprecated():
+        d1 = IMP.atom.LennardJones.setup_particle(m, p1, 1.0)
     sm = IMP.atom.ForceSwitch(min_distance, max_distance)
-    c = IMP.atom.LennardJonesPairScore(sm)
-    r = IMP.core.PairRestraint(c, (p0, p1))
-    m.add_restraint(r)
-    return m, d0, d1, c
+    with IMP.allow_deprecated():
+        c = IMP.atom.LennardJonesPairScore(sm)
+    r = IMP.core.PairRestraint(m, c, (p0, p1))
+    sf = IMP.core.RestraintsScoringFunction([r])
+    return m, sf, d0, d1, c
 
 
 class Tests(IMP.test.TestCase):
@@ -32,7 +35,8 @@ class Tests(IMP.test.TestCase):
     def test_get_set(self):
         """Check LennardJonesPairScore get/set methods"""
         sm = IMP.atom.ForceSwitch(9.0, 10.0)
-        c = IMP.atom.LennardJonesPairScore(sm)
+        with IMP.allow_deprecated():
+            c = IMP.atom.LennardJonesPairScore(sm)
         self.assertEqual(c.get_repulsive_weight(), 1.0)
         c.set_repulsive_weight(5.0)
         self.assertEqual(c.get_repulsive_weight(), 5.0)
@@ -42,7 +46,7 @@ class Tests(IMP.test.TestCase):
 
     def test_value(self):
         """Check score value of LennardJonesPairScore"""
-        m, d0, d1, c = make_test_pair_score()
+        m, sf, d0, d1, c = make_test_pair_score()
 
         box = IMP.algebra.Vector3D(10.0, 20.0, 30.0)
         for r0 in (2.0, 1.0):
@@ -61,7 +65,8 @@ class Tests(IMP.test.TestCase):
                                 c.set_repulsive_weight(rep)
                                 for r in (3.0, 4.0, 5.0):
                                     place_xyzs(d0, d1, box, r)
-                                    score = m.evaluate(False)
+                                    with IMP.allow_deprecated():
+                                        score = sf.evaluate(False)
                                     expected = wd * (rep * (rmin / r) ** 12
                                                      - 2.0 * att * (rmin / r) ** 6)
                                     self.assertAlmostEqual(score, expected,
@@ -69,21 +74,22 @@ class Tests(IMP.test.TestCase):
 
     def test_derivatives(self):
         """Check derivatives of LennardJonesPairScore"""
-        m, d0, d1, c = make_test_pair_score(4.0, 6.0)
+        m, sf, d0, d1, c = make_test_pair_score(4.0, 6.0)
         # Place one particle at the origin and the other at a random position
         # between 1 and 6 angstroms away (not too close since the derivatives
         # are too large there)
         d0.set_coordinates(IMP.algebra.Vector3D(0, 0, 0))
         d1.set_coordinates(IMP.algebra.get_random_vector_on(IMP.algebra.get_unit_sphere_3d())
                            * (random.random() * 5.0 + 1.0))
-        self.assertXYZDerivativesInTolerance(m, d0, 2.0, 5.0)
-        self.assertXYZDerivativesInTolerance(m, d1, 2.0, 5.0)
+        with IMP.allow_deprecated():
+            self.assertXYZDerivativesInTolerance(sf, d0, 2.0, 5.0)
+            self.assertXYZDerivativesInTolerance(sf, d1, 2.0, 5.0)
 
     def test_smoothing(self):
         """Check smoothing of LennardJonesPairScore"""
-        m, d0, d1, c = make_test_pair_score()
-        smm, smd0, smd1, smc = make_test_pair_score(min_distance=4.0,
-                                                    max_distance=5.0)
+        m, sf, d0, d1, c = make_test_pair_score()
+        smm, smsf, smd0, smd1, smc = make_test_pair_score(min_distance=4.0,
+                                                          max_distance=5.0)
         box = IMP.algebra.Vector3D(10.0, 20.0, 30.0)
 
         def place_all(dist):
@@ -94,13 +100,15 @@ class Tests(IMP.test.TestCase):
         # For dist <= min_distance, scores should be identical
         for dist in (3.0, 3.5, 4.0):
             place_all(dist)
-            self.assertAlmostEqual(m.evaluate(False), smm.evaluate(False),
-                                   delta=1e-6)
+            with IMP.allow_deprecated():
+                self.assertAlmostEqual(sf.evaluate(False), smsf.evaluate(False),
+                                       delta=1e-6)
 
         # For dist > max_distance, smoothed score should be zero
         place_all(5.5)
-        self.assertEqual(smm.evaluate(False), 0.0)
-        self.assertNotEqual(m.evaluate(False), 0.0)
+        with IMP.allow_deprecated():
+            self.assertEqual(smsf.evaluate(False), 0.0)
+            self.assertNotEqual(sf.evaluate(False), 0.0)
 
 if __name__ == '__main__':
     IMP.test.main()
