@@ -2,7 +2,7 @@
  *  \file IMP/core/NormalMover.h
  *  \brief A modifier which perturbs a point with a normal distribution.
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2023 IMP Inventors. All rights reserved.
  *
  */
 
@@ -11,6 +11,9 @@
 
 #include <IMP/core/core_config.h>
 #include "MonteCarloMover.h"
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
+#include <cereal/types/vector.hpp>
 
 IMPCORE_BEGIN_NAMESPACE
 
@@ -23,6 +26,16 @@ class IMPCOREEXPORT NormalMover : public MonteCarloMover {
   Float stddev_;
   algebra::VectorKDs originals_;
 
+  friend class cereal::access;
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<MonteCarloMover>(this), pis_, keys_, stddev_);
+    if (std::is_base_of<cereal::detail::InputArchiveBase, Archive>::value) {
+      // clear originals
+      initialize(pis_, keys_, stddev_);
+    }
+  }
+  IMP_OBJECT_SERIALIZE_DECL(NormalMover);
+
   void initialize(ParticleIndexes pis, FloatKeys keys, double radius);
 
  public:
@@ -40,6 +53,7 @@ class IMPCOREEXPORT NormalMover : public MonteCarloMover {
 
   NormalMover(const ParticlesTemp &sc, Float radius);
 #endif
+  NormalMover() {}
 
   void set_sigma(Float sigma) {
     IMP_USAGE_CHECK(sigma > 0, "Sigma must be positive");
@@ -49,9 +63,9 @@ class IMPCOREEXPORT NormalMover : public MonteCarloMover {
   Float get_sigma() const { return stddev_; }
 
  protected:
-  virtual ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
-  virtual MonteCarloMoverResult do_propose() IMP_OVERRIDE;
-  virtual void do_reject() IMP_OVERRIDE;
+  virtual ModelObjectsTemp do_get_inputs() const override;
+  virtual MonteCarloMoverResult do_propose() override;
+  virtual void do_reject() override;
   IMP_OBJECT_METHODS(NormalMover);
 };
 
