@@ -9,7 +9,7 @@
 #include <IMP/Pointer.h>
 #include <IMP/exception.h>
 #include <IMP/random.h>
-#include <boost/random/uniform_real.hpp>
+#include <boost/random/uniform_real_distribution.hpp>
 
 IMPCORE_BEGIN_NAMESPACE
 
@@ -22,7 +22,7 @@ ChecksScoreState::ChecksScoreState(Model *m, double prob)
 }
 
 void ChecksScoreState::do_before_evaluate() {
-  ::boost::uniform_real<> rand(0, 1);
+  ::boost::random::uniform_real_distribution<> rand(0, 1);
   if (rand(random_number_generator) < probability_) {
     set_check_level(USAGE_AND_INTERNAL);
     ++num_checked_;
