@@ -2,7 +2,7 @@
  *  \file IMP/example/ExampleRestraint.h
  *  \brief A restraint on a list of particle pairs.
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -11,6 +11,7 @@
 
 #include <IMP/example/example_config.h>
 #include <IMP/Restraint.h>
+#include <cereal/access.hpp>
 
 IMPEXAMPLE_BEGIN_NAMESPACE
 
@@ -32,10 +33,28 @@ class IMPEXAMPLEEXPORT ExampleRestraint : public Restraint {
       preferably in a Singleton or PairContainer as appropriate.
    */
   ExampleRestraint(Model *m, ParticleIndex p, double k);
+
+  // Default constructor, needed for serialization or Python pickle support
+  ExampleRestraint() {}
+
   void do_add_score_and_derivatives(ScoreAccumulator sa) const
-      IMP_OVERRIDE;
-  ModelObjectsTemp do_get_inputs() const;
+      override;
+  ModelObjectsTemp do_get_inputs() const override;
   IMP_OBJECT_METHODS(ExampleRestraint);
+
+ private:
+  // Serialization support
+  friend class cereal::access;
+  template<class Archive> void serialize(Archive &ar) {
+    // We must save/load everything in the Restraint base class
+    // (e.g. restraint name, Model pointer) plus our own variables p_ and k_
+    ar(cereal::base_class<Restraint>(this), p_, k_);
+  }
+  // ExampleRestraint is polymorphic (e.g. it is stored in
+  // IMP.core.RestraintsScoringFunction as a Restraint, not an
+  // ExampleRestraint) so tell the serialization subsystem how to handle this
+  IMP_OBJECT_SERIALIZE_DECL(ExampleRestraint);
+
 };
 
 IMPEXAMPLE_END_NAMESPACE
