@@ -1,7 +1,5 @@
 import IMP.test
-import sys
 import os
-import re
 
 
 class Tests(IMP.test.ApplicationTestCase):
@@ -17,5 +15,6 @@ class Tests(IMP.test.ApplicationTestCase):
             for e in expected:
                 os.unlink(e)
 
+
 if __name__ == '__main__':
     IMP.test.main()
