@@ -2,7 +2,6 @@
 # This example shows writing a brownian dynamics simulation to a rmf file.
 # It includes a bounding box, restraints and a hierarchy of particles.
 
-from __future__ import print_function, division
 import IMP.atom
 import IMP.rmf
 import RMF
@@ -63,9 +62,8 @@ bd.set_scoring_function(sf)
 
 bd.set_maximum_time_step(10)
 
-name = IMP.create_temporary_file_name("brownian", ".rmf")
-rmf = RMF.create_rmf_file(name)
-rmf.set_description("Brownian dyanmics trajectory with 10fs timestep.\n")
+rmf = RMF.create_rmf_file("brownian.rmf")
+rmf.set_description("Brownian dynamics trajectory with 10fs timestep.\n")
 IMP.rmf.add_hierarchy(rmf, h)
 IMP.rmf.add_restraints(rmf, rs)
 IMP.rmf.add_geometry(rmf, IMP.display.BoundingBoxGeometry(bb))
