@@ -40,8 +40,8 @@ double ChiFreeScore::compute_score(const Profile* exp_profile,
 
   IMP_NEW(Profile, exp_profile_selection, ());
   IMP_NEW(Profile, model_profile_selection, ());
-  Eigen::VectorXf qs(ns_), errors(ns_);
-  Eigen::VectorXf exp_intensities(ns_), model_intensities(ns_);
+  Eigen::VectorXd qs(ns_), errors(ns_);
+  Eigen::VectorXd exp_intensities(ns_), model_intensities(ns_);
 
   // repeat K_ times
   for (unsigned int k = 0; k < K_; k++) {
