@@ -2,15 +2,14 @@
  *  \file IMP/spb/RMSDMetric.h
  *  \brief Distance RMSD Metric
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPSPB_RMSD_METRIC_H
 #define IMPSPB_RMSD_METRIC_H
 
-#include <IMP/algebra.h>
-#include <IMP/statistics.h>
-#include "spb_config.h"
+#include <IMP/spb/spb_config.h>
+#include <IMP/statistics/Metric.h>
 
 IMPSPB_BEGIN_NAMESPACE
 
@@ -29,8 +28,8 @@ class IMPSPBEXPORT RMSDMetric : public statistics::Metric {
   Float get_weight(unsigned i);
 
   // IMP_METRIC(RMSDMetric);
-  double get_distance(unsigned int i, unsigned int j) const IMP_OVERRIDE;
-  unsigned int get_number_of_items() const IMP_OVERRIDE;
+  double get_distance(unsigned int i, unsigned int j) const override;
+  unsigned int get_number_of_items() const override;
   IMP_OBJECT_METHODS(RMSDMetric);
 };
 
