@@ -2,16 +2,16 @@
  *  \file IMP/spb/spb_parser.h
  *  \brief SPB Parser
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
 #ifndef IMPSPB_SPB_PARSER_H
 #define IMPSPB_SPB_PARSER_H
-#include <IMP.h>
-#include <IMP/spb.h>
+
 #include <string>
-#include "spb_config.h"
+#include <IMP/spb/spb_main.h>
+#include <IMP/spb/spb_config.h>
 
 IMPSPB_BEGIN_NAMESPACE
 
